@@ -7,7 +7,7 @@ from collections import OrderedDict
 import hashlib
 import numpy as np
 import warnings
-from pyiron_base import GenericParameters
+from pyiron_base import GenericParameters, state
 from pyiron_atomistics.lammps.units import LAMMPS_UNIT_CONVERSIONS
 
 __author__ = "Joerg Neugebauer, Sudarsan Surendralal, Jan Janssen"
@@ -99,7 +99,7 @@ class LammpsControl(GenericParameters):
                 + "variable___dumptime   equal 100\n"
                 + "variable___thermotime equal 100\n"
                 + "dump___1              all custom ${dumptime} dump.out id type xsu ysu zsu fx fy fz vx vy vz\n"
-                + "dump_modify___1       sort id format line \"%d %d %20.15g %20.15g %20.15g %20.15g %20.15g %20.15g %20.15g %20.15g %20.15g\"\n"
+                + 'dump_modify___1       sort id format line "%d %d %20.15g %20.15g %20.15g %20.15g %20.15g %20.15g %20.15g %20.15g %20.15g"\n'
                 + "thermo_style          custom step temp pe etotal pxx pxy pxz pyy pyz pzz vol\n"
                 + "thermo_modify         format float %20.15g\n"
                 + "thermo                ${thermotime}\n"
@@ -138,10 +138,11 @@ class LammpsControl(GenericParameters):
 
         # Normalize pressure to a list of 6 entries of either float or NoneType type.
         if len(pressure) > 6:
-            raise ValueError("Pressure can have a maximum of 6 values, (x, y, z, xy, xz, and yz), but got " +
-                             "{}".format(len(pressure)))
-        pressure = [float(p) if p is not None else None
-                    for p in pressure]
+            raise ValueError(
+                "Pressure can have a maximum of 6 values, (x, y, z, xy, xz, and yz), but got "
+                + "{}".format(len(pressure))
+            )
+        pressure = [float(p) if p is not None else None for p in pressure]
         pressure += (6 - len(pressure)) * [None]
 
         if all(p is None for p in pressure):
@@ -149,31 +150,43 @@ class LammpsControl(GenericParameters):
 
         # If necessary, rotate the pressure tensor to the Lammps coordinate frame.
         # Isotropic, hydrostatic pressures are rotation invariant.
-        if not np.isclose(np.matrix.trace(rotation_matrix), 3) and not self._is_isotropic_hydrostatic(pressure):
+        if not np.isclose(
+            np.matrix.trace(rotation_matrix), 3
+        ) and not self._is_isotropic_hydrostatic(pressure):
             if any(p is None for p in pressure):
-                raise ValueError("Cells which are not orthorhombic or an upper-triangular cell are incompatible with Lammps "
-                                 "constant pressure calculations unless the entire pressure tensor is defined. "
-                                 "The reason is that Lammps demands such cells be represented with an "
-                                 "upper-triangular unit cell, thus a rotation between Lammps and pyiron coordinate "
-                                 "frames is required; it is not possible to rotate the pressure tensor if any of "
-                                 "its components is None.")
+                raise ValueError(
+                    "Cells which are not orthorhombic or an upper-triangular cell are incompatible with Lammps "
+                    "constant pressure calculations unless the entire pressure tensor is defined. "
+                    "The reason is that Lammps demands such cells be represented with an "
+                    "upper-triangular unit cell, thus a rotation between Lammps and pyiron coordinate "
+                    "frames is required; it is not possible to rotate the pressure tensor if any of "
+                    "its components is None."
+                )
             pxx, pyy, pzz, pxy, pxz, pyz = pressure
             pressure_tensor = np.array(
-                [[pxx, pxy, pxz],
-                 [pxy, pyy, pyz],
-                 [pxz, pyz, pzz]]
+                [[pxx, pxy, pxz], [pxy, pyy, pyz], [pxz, pyz, pzz]]
+            )
+            lammps_pressure_tensor = (
+                rotation_matrix.T @ pressure_tensor @ rotation_matrix
+            )
+            pressure = list(
+                lammps_pressure_tensor[[0, 1, 2, 0, 0, 1], [0, 1, 2, 1, 2, 2]]
             )
-            lammps_pressure_tensor = rotation_matrix.T @ pressure_tensor @ rotation_matrix
-            pressure = list(lammps_pressure_tensor[[0, 1, 2, 0, 0, 1], [0, 1, 2, 1, 2, 2]])
 
-        return [(p * LAMMPS_UNIT_CONVERSIONS[self["units"]]["pressure"]
-                 if p is not None
-                 else p)
-                for p in pressure]
+        return [
+            (
+                p * LAMMPS_UNIT_CONVERSIONS[self["units"]]["pressure"]
+                if p is not None
+                else p
+            )
+            for p in pressure
+        ]
 
     @staticmethod
     def _is_isotropic_hydrostatic(pressure):
-        axial_all_alike = None not in pressure[:3] and np.allclose(pressure[:3], pressure[0])
+        axial_all_alike = None not in pressure[:3] and np.allclose(
+            pressure[:3], pressure[0]
+        )
         shear_all_none = all(p is None for p in pressure[3:])
         shear_all_zero = None not in pressure[3:] and np.allclose(pressure[3:], 0)
         return axial_all_alike and (shear_all_none or shear_all_zero)
@@ -185,8 +198,8 @@ class LammpsControl(GenericParameters):
         max_iter=100000,
         pressure=None,
         n_print=100,
-        style='cg',
-        rotation_matrix=None
+        style="cg",
+        rotation_matrix=None,
     ):
         """
         Sets parameters required for minimization.
@@ -218,6 +231,11 @@ class LammpsControl(GenericParameters):
         # defaults stay consistent!
 
         max_evaluations = 100 * max_iter
+        if n_print > max_iter:
+            state.logger.warning(
+                "n_print larger than max_iter, adjusting to n_print=max_iter"
+            )
+            n_print = max_iter
 
         if self["units"] not in LAMMPS_UNIT_CONVERSIONS.keys():
             raise NotImplementedError
@@ -234,10 +252,12 @@ class LammpsControl(GenericParameters):
                 str_press = " iso {}".format(pressure)
             else:
                 str_press = ""
-                for ii, (press, str_axis) in enumerate(zip(pressure, ["x","y","z","xy","xz","yz"])):
+                for ii, (press, str_axis) in enumerate(
+                    zip(pressure, ["x", "y", "z", "xy", "xz", "yz"])
+                ):
                     if press is not None:
-                        str_press += ' {} {}'.format(str_axis, press)
-                        if ii>2:
+                        str_press += " {} {}".format(str_axis, press)
+                        if ii > 2:
                             self._force_skewed = True
                 if len(str_press) > 1:
                     str_press += " couple none"
@@ -256,7 +276,7 @@ class LammpsControl(GenericParameters):
         self.remove_keys(["run", "velocity"])
         self.modify(
             variable___dumptime="equal " + str(n_print),
-            variable___thermotime="equal " + str(n_print)
+            variable___thermotime="equal " + str(n_print),
         )
 
     def calc_static(self):
@@ -337,7 +357,7 @@ class LammpsControl(GenericParameters):
         delta_temp=None,
         delta_press=None,
         job_name="",
-        rotation_matrix=None
+        rotation_matrix=None,
     ):
         """
         Set an MD calculation within LAMMPS. Nosé Hoover is used by default.
@@ -415,12 +435,14 @@ class LammpsControl(GenericParameters):
         # Transform temperature
         if temperature is not None:
             temperature = np.array([temperature], dtype=float).flatten()
-            if len(temperature)==1:
-                temperature = np.array(2*temperature.tolist())
+            if len(temperature) == 1:
+                temperature = np.array(2 * temperature.tolist())
             elif len(temperature) != 2:
-                raise ValueError("At most two temperatures can be provided "
-                                 "(for a linearly ramping target temperature), "
-                                 "but got {}".format(len(temperature)))
+                raise ValueError(
+                    "At most two temperatures can be provided "
+                    "(for a linearly ramping target temperature), "
+                    "but got {}".format(len(temperature))
+                )
             temperature *= temperature_units
 
         # Apply initial overheating (default uses the theorem of equipartition of energy between KE and PE)
@@ -431,20 +453,26 @@ class LammpsControl(GenericParameters):
             seed = self.generate_seed_from_job(job_name=job_name)
         if seed <= 0:
             raise ValueError("Seed must be a positive integer larger than 0")
-            
+
         # Set thermodynamic ensemble
         if pressure is not None:  # NPT
             if temperature is None or temperature.min() <= 0:
-                raise ValueError("Target temperature for fix nvt/npt/nph cannot be 0 or negative")
+                raise ValueError(
+                    "Target temperature for fix nvt/npt/nph cannot be 0 or negative"
+                )
 
             self._force_skewed = False
             pressure = self.pressure_to_lammps(pressure, rotation_matrix)
 
             if np.isscalar(pressure):
-                pressure_string = " iso {0} {0} {1}".format(pressure, pressure_damping_timescale)
+                pressure_string = " iso {0} {0} {1}".format(
+                    pressure, pressure_damping_timescale
+                )
             else:
                 pressure_string = ""
-                for ii, (coord, value) in enumerate(zip(["x", "y", "z", "xy", "xz", "yz"], pressure)):
+                for ii, (coord, value) in enumerate(
+                    zip(["x", "y", "z", "xy", "xz", "yz"], pressure)
+                ):
                     if value is not None:
                         pressure_string += " {0} {1} {1} {2}".format(
                             coord, value, pressure_damping_timescale
@@ -472,7 +500,9 @@ class LammpsControl(GenericParameters):
                 fix_ensemble_str += pressure_string
         elif temperature is not None:  # NVT
             if temperature.min() <= 0:
-                raise ValueError("Target temperature for fix nvt/npt/nph cannot be 0 or negative")
+                raise ValueError(
+                    "Target temperature for fix nvt/npt/nph cannot be 0 or negative"
+                )
 
             if langevin:  # NVT(Langevin)
                 fix_ensemble_str = "all nve"
@@ -514,7 +544,7 @@ class LammpsControl(GenericParameters):
                 temperature=initial_temperature,
                 seed=seed,
                 gaussian=True,
-                job_name=job_name
+                job_name=job_name,
             )
 
     def calc_vcsgc(
@@ -522,7 +552,7 @@ class LammpsControl(GenericParameters):
         mu,
         ordered_element_list,
         target_concentration=None,
-        kappa=1000.,
+        kappa=1000.0,
         mc_step_interval=100,
         swap_fraction=0.1,
         temperature_mc=None,
@@ -539,7 +569,7 @@ class LammpsControl(GenericParameters):
         initial_temperature=None,
         langevin=False,
         job_name="",
-        rotation_matrix=None
+        rotation_matrix=None,
     ):
         """
         Run variance-constrained semi-grand-canonical MD/MC for a binary system. In addition to VC-SGC arguments, all
@@ -592,7 +622,7 @@ class LammpsControl(GenericParameters):
             initial_temperature=initial_temperature,
             langevin=langevin,
             job_name=job_name,
-            rotation_matrix=rotation_matrix
+            rotation_matrix=rotation_matrix,
         )
 
         if self["units"] not in LAMMPS_UNIT_CONVERSIONS.keys():
@@ -609,7 +639,9 @@ class LammpsControl(GenericParameters):
             seed = self.generate_seed_from_job(job_name=job_name)
 
         if set(mu.keys()) != set(ordered_element_list):
-            raise ValueError("Exactly one chemical potential must be given for each element treated by the potential.")
+            raise ValueError(
+                "Exactly one chemical potential must be given for each element treated by the potential."
+            )
 
         calibrating_el = ordered_element_list[0]
         # Apply the actual SGC string
@@ -617,24 +649,40 @@ class LammpsControl(GenericParameters):
             str(mc_step_interval),
             str(swap_fraction),
             str(temperature_mc),
-            str(" ".join(str((mu[el] - mu[calibrating_el]) * energy_units) for el in ordered_element_list[1:])),
+            str(
+                " ".join(
+                    str((mu[el] - mu[calibrating_el]) * energy_units)
+                    for el in ordered_element_list[1:]
+                )
+            ),
             str(seed),
         )
 
         # Add VC to the SGC if target concentrations were provided
         if target_concentration is not None:
             if set(target_concentration.keys()) != set(ordered_element_list):
-                raise ValueError("Exactly one target concentration must be given for each element treated by the "
-                                 "potential.")
+                raise ValueError(
+                    "Exactly one target concentration must be given for each element treated by the "
+                    "potential."
+                )
 
             if not np.isclose(np.sum([v for _, v in target_concentration.items()]), 1):
-                raise ValueError("Target concentrations must sum to 1 but were {}.".format(
-                    np.sum([v for _, v in target_concentration.items()])
-                ))
+                raise ValueError(
+                    "Target concentrations must sum to 1 but were {}.".format(
+                        np.sum([v for _, v in target_concentration.items()])
+                    )
+                )
 
             fix_vcsgc_str += " variance {0} {1}".format(
                 str(kappa),
-                str(" ".join([str(target_concentration[el]) for el in ordered_element_list[1:]]))
+                str(
+                    " ".join(
+                        [
+                            str(target_concentration[el])
+                            for el in ordered_element_list[1:]
+                        ]
+                    )
+                ),
             )
 
         # Set optional windowing parameters
@@ -647,94 +695,117 @@ class LammpsControl(GenericParameters):
                 raise ValueError("Window size must be a fraction between 0.5 and 1")
             fix_vcsgc_str += " window_size {0}".format(window_size)
 
-        self.modify(
-            fix___vcsgc=fix_vcsgc_str,
-            append_if_not_present=True
-        )
+        self.modify(fix___vcsgc=fix_vcsgc_str, append_if_not_present=True)
 
     def measure_mean_value(self, key, every=1, repeat=None, name=None, atom=False):
         """
-            Args:
-                key (str): property to take an average value of (e.g. 'energy_pot' v.i.)
-                every (int): number of steps there should be between two measurements
-                repeat (int): number of measurements for each output (default: n_print/every)
-                name (str): name to give in the output string (ignored if a pyiron predefined tag is used)
+        Args:
+            key (str): property to take an average value of (e.g. 'energy_pot' v.i.)
+            every (int): number of steps there should be between two measurements
+            repeat (int): number of measurements for each output (default: n_print/every)
+            name (str): name to give in the output string (ignored if a pyiron predefined tag is used)
 
-            Comments:
-                Currently available keys: 'energy_pot', 'energy_tot', 'temperature', 'volume',
-                                          'pressures', 'positions', 'forces, 'velocities'
-                Future keys: 'cells'
+        Comments:
+            Currently available keys: 'energy_pot', 'energy_tot', 'temperature', 'volume',
+                                      'pressures', 'positions', 'forces, 'velocities'
+            Future keys: 'cells'
         """
 
-        if every<=0:
-            raise AssertionError('every must be a positive integer')
+        if every <= 0:
+            raise AssertionError("every must be a positive integer")
         if repeat is None:
-            self['variable___mean_repeat_times'] = 'equal round(${thermotime}/'+str(every)+')'
+            self["variable___mean_repeat_times"] = (
+                "equal round(${thermotime}/" + str(every) + ")"
+            )
         else:
-            self['variable___mean_repeat_times'] = 'equal {}'.format(repeat)
-        if key=='energy_pot':
-            self._measure_mean_value('energy_pot', 'pe', every)
-        elif key=='energy_tot':
-            self._measure_mean_value('energy_tot', 'etotal', every)
-        elif key=='temperature':
-            self._measure_mean_value('temperature', 'temp', every)
-        elif key=='volume':
-            self._measure_mean_value('volume', 'vol', every)
-        elif key=='pressures':
-            self._measure_mean_value('pressure', ['pxx', 'pyy', 'pzz', 'pxy', 'pxz', 'pyz'], every)
-        elif key=='positions':
-            self['compute___unwrap'] = 'all property/atom xu yu zu'
-            self['fix___mean_positions'] = ('all ave/atom '
-                                            +str(every)
-                                            +' ${mean_repeat_times} ${thermotime} c_unwrap[*]'
-                                           )
-            self['dump___1'] = self['dump___1']+' '+' '.join(['f_mean_positions[{}]'.format(ii+1) for ii in range(3)])
-            self['dump_modify___1'] = self['dump_modify___1'][:-1]+' '+' '.join(['%20.15g']*3)+'"'
-        elif key=='forces':
-            self._measure_mean_value('forces', ['fx', 'fy', 'fz'], every, atom=True)
-        elif key=='velocities':
-            self._measure_mean_value('velocities', ['vx', 'vy', 'vz'], every, atom=True)
+            self["variable___mean_repeat_times"] = "equal {}".format(repeat)
+        if key == "energy_pot":
+            self._measure_mean_value("energy_pot", "pe", every)
+        elif key == "energy_tot":
+            self._measure_mean_value("energy_tot", "etotal", every)
+        elif key == "temperature":
+            self._measure_mean_value("temperature", "temp", every)
+        elif key == "volume":
+            self._measure_mean_value("volume", "vol", every)
+        elif key == "pressures":
+            self._measure_mean_value(
+                "pressure", ["pxx", "pyy", "pzz", "pxy", "pxz", "pyz"], every
+            )
+        elif key == "positions":
+            self["compute___unwrap"] = "all property/atom xu yu zu"
+            self["fix___mean_positions"] = (
+                "all ave/atom "
+                + str(every)
+                + " ${mean_repeat_times} ${thermotime} c_unwrap[*]"
+            )
+            self["dump___1"] = (
+                self["dump___1"]
+                + " "
+                + " ".join(["f_mean_positions[{}]".format(ii + 1) for ii in range(3)])
+            )
+            self["dump_modify___1"] = (
+                self["dump_modify___1"][:-1] + " " + " ".join(["%20.15g"] * 3) + '"'
+            )
+        elif key == "forces":
+            self._measure_mean_value("forces", ["fx", "fy", "fz"], every, atom=True)
+        elif key == "velocities":
+            self._measure_mean_value("velocities", ["vx", "vy", "vz"], every, atom=True)
         elif name is not None:
-            if '**' in key:
-                warnings.warn('** is replaced by ^ (as it is understood by LAMMPS)')
-                key = key.replace('**', '^')
+            if "**" in key:
+                warnings.warn("** is replaced by ^ (as it is understood by LAMMPS)")
+                key = key.replace("**", "^")
             self._measure_mean_value(name, key, every, atom)
         else:
-            raise NotImplementedError(key+' is not implemented')
+            raise NotImplementedError(key + " is not implemented")
 
     def energy_pot_per_atom(self):
         """
         Enable the output of atomic energies.  This will add an additional key 'energy_pot_per_atom' to the HDF output.
         """
-        if self['compute___energy_pot_per_atom'] is None:
-            self['compute___energy_pot_per_atom'] = 'all pe/atom'
-            self['dump___1'] += ' c_energy_pot_per_atom'
-            self['dump_modify___1'] = self['dump_modify___1'][:-1] + ' %20.15g"'
+        if self["compute___energy_pot_per_atom"] is None:
+            self["compute___energy_pot_per_atom"] = "all pe/atom"
+            self["dump___1"] += " c_energy_pot_per_atom"
+            self["dump_modify___1"] = self["dump_modify___1"][:-1] + ' %20.15g"'
 
     def _set_group_by_id(self, group_name, ids):
         if len(ids) < 1:
-            raise ValueError('Group ids must have at least length one, but got {}'.format(ids))
-        if np.any([isinstance(id_, bool) or not isinstance(id_, (int, np.integer)) for id_ in ids]):
+            raise ValueError(
+                "Group ids must have at least length one, but got {}".format(ids)
+            )
+        if np.any(
+            [
+                isinstance(id_, bool) or not isinstance(id_, (int, np.integer))
+                for id_ in ids
+            ]
+        ):
             # Note: it turns out bool is a subclass of int. Weird, eh.
-            raise TypeError('Group ids must be integers, but got {}'.format(ids))
+            raise TypeError("Group ids must be integers, but got {}".format(ids))
         if np.any(np.array(ids) < 0):
-            raise ValueError('Group ids must be non-negative to be parsed by Lammps, but got {}'.format(ids))
-        self['group___{}'.format(group_name)] = 'id {}'.format(' '.join(np.array(ids).astype(int).astype(str)))
+            raise ValueError(
+                "Group ids must be non-negative to be parsed by Lammps, but got {}".format(
+                    ids
+                )
+            )
+        self["group___{}".format(group_name)] = "id {}".format(
+            " ".join(np.array(ids).astype(int).astype(str))
+        )
 
     def _fix_with_three_vector(self, ids, vector, fix_string, conversion):
         if len(vector) != 3:
-            raise ValueError('{} must have three components, but got {}'.format(fix_string, vector))
+            raise ValueError(
+                "{} must have three components, but got {}".format(fix_string, vector)
+            )
         vector = list(vector)
         for i, v in enumerate(vector):
             if v is None:
-                vector[i] = 'NULL'
+                vector[i] = "NULL"
             else:
                 vector[i] = str(v * conversion)
-        name = str(hash(tuple(ids))).replace('-', 'm')  # A unique name for the group
+        name = str(hash(tuple(ids))).replace("-", "m")  # A unique name for the group
         self._set_group_by_id(name, ids)
-        self['fix___{}_{}'.format(fix_string.replace(' ', '_'), name)] = '{} {} {}'.format(
-            name, fix_string, ' '.join(vector)
-        )
+        self[
+            "fix___{}_{}".format(fix_string.replace(" ", "_"), name)
+        ] = "{} {} {}".format(name, fix_string, " ".join(vector))
 
     def fix_move_linear_by_id(self, ids, velocity):
         """
@@ -751,10 +822,17 @@ class LammpsControl(GenericParameters):
             further modifying this capability. Further, it will malfunction if the Lammps coordinate frame and pyiron
             coordinate frame differ.
         """
-        warnings.warn('This fix does not exclude these atoms from other fixes. You may wish to combine this call with '
-                      '`selective_dynamics` on your corresponding structure. Further, it will malfunction if the '
-                      'Lammps coordinate frame and pyiron coordinate frame differ.')
-        self._fix_with_three_vector(ids, velocity, 'move linear', LAMMPS_UNIT_CONVERSIONS[self["units"]]["velocity"])
+        warnings.warn(
+            "This fix does not exclude these atoms from other fixes. You may wish to combine this call with "
+            "`selective_dynamics` on your corresponding structure. Further, it will malfunction if the "
+            "Lammps coordinate frame and pyiron coordinate frame differ."
+        )
+        self._fix_with_three_vector(
+            ids,
+            velocity,
+            "move linear",
+            LAMMPS_UNIT_CONVERSIONS[self["units"]]["velocity"],
+        )
 
     def fix_setforce_by_id(self, ids, force):
         """
@@ -766,49 +844,98 @@ class LammpsControl(GenericParameters):
 
         Warning: This fix will malfunction (silently) if the Lammps coordinate frame and pyiron coordinate frame differ.
         """
-        warnings.warn('This fix will malfunction (silently) if the Lammps coordinate frame and pyiron coordinate frame '
-                      'differ.')
-        self._fix_with_three_vector(ids, force, 'setforce', LAMMPS_UNIT_CONVERSIONS[self["units"]]["force"])
+        warnings.warn(
+            "This fix will malfunction (silently) if the Lammps coordinate frame and pyiron coordinate frame "
+            "differ."
+        )
+        self._fix_with_three_vector(
+            ids, force, "setforce", LAMMPS_UNIT_CONVERSIONS[self["units"]]["force"]
+        )
 
     def _measure_mean_value(self, key_pyiron, key_lmp, every, atom=False):
         """
-            Args:
-                key (str): property to take an average value of (e.g. 'energy_pot' v.i.)
-                every (int): number of steps there should be between two measurements
-                repeat (int): number of measurements for each output (default: n_print/every)
-                freq (int): output frequency (default: n_print)
+        Args:
+            key (str): property to take an average value of (e.g. 'energy_pot' v.i.)
+            every (int): number of steps there should be between two measurements
+            repeat (int): number of measurements for each output (default: n_print/every)
+            freq (int): output frequency (default: n_print)
 
-            Comments:
-                Currently available keys: 'energy_pot', 'energy_tot', 'temperature', 'volume',
-                                          'pressures', 'psitions', 'forces, 'velocities'
-                Future keys: 'cells'
+        Comments:
+            Currently available keys: 'energy_pot', 'energy_tot', 'temperature', 'volume',
+                                      'pressures', 'psitions', 'forces, 'velocities'
+            Future keys: 'cells'
         """
         if isinstance(key_lmp, str):
-            self['variable___{}'.format(key_pyiron)] = 'equal {}'.format(key_lmp)
-            self['fix___mean_{}'.format(key_pyiron)] = ('all ave/time '
-                                                        +str(every)
-                                                        +' ${mean_repeat_times} ${thermotime} v_'
-                                                        +str(key_pyiron))
-            self['thermo_style'] = self['thermo_style']+' f_mean_{}'.format(key_pyiron)
+            self["variable___{}".format(key_pyiron)] = "equal {}".format(key_lmp)
+            self["fix___mean_{}".format(key_pyiron)] = (
+                "all ave/time "
+                + str(every)
+                + " ${mean_repeat_times} ${thermotime} v_"
+                + str(key_pyiron)
+            )
+            self["thermo_style"] = self["thermo_style"] + " f_mean_{}".format(
+                key_pyiron
+            )
         else:
             if atom is True:
                 for ii, _ in enumerate(key_lmp):
-                    self['variable___{}_{}'.format(key_pyiron, ii)] = 'atom {}'.format(key_lmp[ii])
-                self['fix___mean_{}'.format(key_pyiron)] = ('all ave/atom '
-                                                            +str(every)+
-                                                            ' ${mean_repeat_times} ${thermotime} '
-                                                            +str(' '.join(['v_{}_{}'.format(key_pyiron, ii) for ii in range(len(key_lmp))]))
-                                                           )
-                self['dump___1'] = self['dump___1']+' '+' '.join(['f_mean_{}[{}]'.format(key_pyiron, ii+1) for ii in range(len(key_lmp))])
-                self['dump_modify___1'] = self['dump_modify___1'][:-1]+' '+' '.join(['%20.15g']*len(key_lmp))+'"'
+                    self["variable___{}_{}".format(key_pyiron, ii)] = "atom {}".format(
+                        key_lmp[ii]
+                    )
+                self["fix___mean_{}".format(key_pyiron)] = (
+                    "all ave/atom "
+                    + str(every)
+                    + " ${mean_repeat_times} ${thermotime} "
+                    + str(
+                        " ".join(
+                            [
+                                "v_{}_{}".format(key_pyiron, ii)
+                                for ii in range(len(key_lmp))
+                            ]
+                        )
+                    )
+                )
+                self["dump___1"] = (
+                    self["dump___1"]
+                    + " "
+                    + " ".join(
+                        [
+                            "f_mean_{}[{}]".format(key_pyiron, ii + 1)
+                            for ii in range(len(key_lmp))
+                        ]
+                    )
+                )
+                self["dump_modify___1"] = (
+                    self["dump_modify___1"][:-1]
+                    + " "
+                    + " ".join(["%20.15g"] * len(key_lmp))
+                    + '"'
+                )
             else:
                 for ii, _ in enumerate(key_lmp):
-                    self['variable___{}_{}'.format(key_pyiron, ii)] = 'equal {}'.format(key_lmp[ii])
-                self['fix___mean_{}'.format(key_pyiron)] = ('all ave/time '
-                                                            +str(every)
-                                                            +' ${mean_repeat_times} ${thermotime} '
-                                                            +str(' '.join(['v_{}_{}'.format(key_pyiron, ii) for ii in range(len(key_lmp))]))
-                                                           )
-                self['thermo_style'] = (self['thermo_style']
-                                        +' '
-                                        +' '.join(['f_mean_{}[{}]'.format(key_pyiron, ii+1) for ii in range(len(key_lmp))]))
+                    self["variable___{}_{}".format(key_pyiron, ii)] = "equal {}".format(
+                        key_lmp[ii]
+                    )
+                self["fix___mean_{}".format(key_pyiron)] = (
+                    "all ave/time "
+                    + str(every)
+                    + " ${mean_repeat_times} ${thermotime} "
+                    + str(
+                        " ".join(
+                            [
+                                "v_{}_{}".format(key_pyiron, ii)
+                                for ii in range(len(key_lmp))
+                            ]
+                        )
+                    )
+                )
+                self["thermo_style"] = (
+                    self["thermo_style"]
+                    + " "
+                    + " ".join(
+                        [
+                            "f_mean_{}[{}]".format(key_pyiron, ii + 1)
+                            for ii in range(len(key_lmp))
+                        ]
+                    )
+                )
