@@ -33,6 +33,6 @@ class Sphinx(SphinxInteractive):
         super(Sphinx, self).__init__(project, job_name)
         self.__name__ = "Sphinx"
         self.__version__ = (
-            None
-        )  # Reset the version number to the executable is set automatically
+            None  # Reset the version number to the executable is set automatically
+        )
         self._executable_activate(enforce=True)
